===============================
Nova-lxd Feature Support Matrix
===============================

The following support matrix reflects the nova-lxd that is currently available
or is available at the time of release.

.. Note::

  Notes for each operation of this matrix were basically quoted from
  `support-matrix of Nova <https://docs.openstack.org/nova/latest/user/support-matrix.html>`_.


.. _driver_support_matrix:

.. support_matrix:: support-matrix.ini
